@@ -1,5 +1,9 @@
 # -*- coding: utf-8 -*-
-from qtpy.QtQml import qmlRegisterType, qmlRegisterSingletonType
+from qtpy.QtQml import qmlRegisterType
+try:
+    from qtpy.QtQml import qmlRegisterSingletonType
+except ImportError:
+    pass
 
 from .projectbrowser import ProjectBrowser
 from .filewatcher import FileWatcher
